## cdist-type__package_pip(7)

### Nico Schottelius

`<nico-cdist--@--schottelius.org>`

## 1. NAME

cdist-type__package_pip - Manage packages with pip

## 2. DESCRIPTION

Pip is used in Python environments to install packages. It is also included in the python virtualenv environment.

## 3. REQUIRED PARAMETERS

None

## 4. OPTIONAL PARAMETERS

name
  If supplied, use the name and not the object id as the package name.
pip
  Instead of using pip from PATH, use the specific pip path.
state
  Either "present" or "absent", defaults to "present"

## 5. EXAMPLES

    # Install a package
    __package_pip pyro --state present

    # Use pip in a virtualenv located at /root/shinken_virtualenv
    __package_pip pyro --state present --pip /root/shinken_virtualenv/bin/pip

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__package(7)

## 7. COPYING

Copyright (C) 2012 Nico Schottelius. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).